@@ -4,34 +4,39 @@ from .tokenizer import Tokenizer
 from .scorer import Scorer
 
 
-def loadingBarCallback(done, total):
-    numOfTicks = 50
-    percentage = int(done/total*100)
-    print('done: ' + '-'* int(done/total* numOfTicks) + f'{percentage} %', end="\r")
-    if percentage == 100: print('\n')
+# def loadingBarCallback(done, total):
+#     numOfTicks = 50
+#     percentage = int(done/total*100)
+#     print('done: ' + '-'* int(done/total* numOfTicks) + f'{percentage} %', end="\r")
+#     if percentage == 100: print('\n')
 
 def getRanking(repo: data_retriveal.RepoRetriveal, pullNumber, 
                numberOfPulls=30, numberOfCommits=30):
+    """
+    Given a repository and a pull number, returns a rank of possible revisors:
 
+    Args:
+        repo(data_retriveal.RepoRetriveal) : the repository
+        pullNumber(int): the number of the pull
+        numberOfPulls(int): number of pulls you want to retrieve, defaults to 30
+        numberOfCommits(int): number of commits you want to retrieve, defaults to 30
+
+    Raises:
+        requests.HTTPError: the repository or the pull number is invalid.
+    """
     scorer = Scorer()
     invertedFile = InvertedFile()
 
     newPull = repo.getPullByNumber(pullNumber)
 
     print('collecting pulls...')
-    done = 0
     for pull in repo.getPullIterable(pullNumber, numberOfPulls):
-        done += 1
-        loadingBarCallback(done, numberOfPulls)
         files = repo.getPullFiles(pull)
         pullTokenFreqs = Tokenizer.getTokenFreqs(files)
         invertedFile.add(pull, pullTokenFreqs)
 
     print('collecting commits...')
-    done = 0
-    for commit in repo.getCommitsIterable(pull.date, numberOfCommits):
-        done += 1
-        loadingBarCallback(done, numberOfCommits)
+    for commit in repo.getCommitsIterable(newPull.date, numberOfCommits):
         files = repo.getCommitFiles(commit)
         commitTokenFreqs = Tokenizer.getTokenFreqs(files)
         invertedFile.add(commit, commitTokenFreqs)
